@@ -32,7 +32,7 @@ class Directory(FlatDict):
     @classmethod
     def from_local(cls, path: str) -> "Directory":
         local_mapper = fsspec.get_mapper(f"file://{os.path.abspath(path)}")
-        return cls(local_mapper)
+        return cls({k: File(content=v) for k, v in local_mapper.items()})
 
     @classmethod
     def from_cookiecutter(
